SliverPullUpRefresh class

SliverPullUpRefresh widget for sliver-based scroll views like CustomScrollView. Enables pull-up-to-refresh behavior similar to PullUpRefresh, but supports slivers.

Inheritance

Constructors

SliverPullUpRefresh({Key? key, required PullUpCallback onRefresh, required List<Widget> slivers, double triggerDistance = 60.0, double indicatorSize = 36.0, Color? indicatorColor, bool autoPull = false, int pullDuration = 5000, double slideDistance = 16.0, ScrollController? controller})
const

Properties

autoPull → bool
final
controller → ScrollController?
final
hashCode → int
The hash code for this object.
no setterinherited
indicatorColor → Color?
final
indicatorSize → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onRefresh → PullUpCallback
final
pullDuration → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slideDistance → double
final
slivers → List<Widget>
final
triggerDistance → double
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<SliverPullUpRefresh>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited